@@ -30,9 +30,9 @@
 #include "metadata.h"
 #include "interface.h"
 #include "note.h"
-#include "serializer.h"
-#include "deserializer.h"
 #include "note_list_store.h"
+#include "storage.h"
+#include "note_buffer.h"
 
 #define _(String)gettext(String)
 
@@ -43,6 +43,7 @@ Note* note_create_new()
 	note->ui = ui;
 	note->active_tags = NULL;
 	note->tags = NULL;
+	note->guid = get_uuid();
 	note->create_date = 0;
 	note->last_change_date = 0;
 	note->last_metadata_change_date = 0;
@@ -53,7 +54,7 @@ Note* note_create_new()
 void note_free(Note *note)
 {
 	g_free(note->ui);
-	g_free(note->filename);
+	g_free(note->content);
 	g_free(note->title);
 	g_free(note->guid);
 	g_slist_free(note->active_tags);
@@ -205,15 +206,15 @@ void note_save(Note *note)
 	if (note->y == 0) {
 		note->y = 1;
 	}
+	
+	/* Clear note content, then set it with fresh data from the text buffer */
+	g_free(note->content);
+	note->content = note_buffer_get_xml(buffer);
 
-	app_data = app_data_get();
-
-	/* Set start and end iterators for serialization */
-	gtk_text_buffer_get_bounds(buffer, &start, &end);
-
-	/* Start serialization */
-	serialize_note(note);
+	/* Save the complete note */
+	storage_save_note(note);
 
+	app_data = app_data_get();	
 	/* If first save, add to list of all notes */
 	if (!note_list_store_find(app_data->note_store, note)) {
 		note_list_store_add(app_data->note_store, note, NULL);
@@ -231,11 +232,21 @@ void note_close_window(Note *note)
 	HildonWindow *window = note->ui->window;
 	AppData *app_data = app_data_get();
 	guint count = g_list_length(app_data->open_notes);
-
+	GList  *listeners = note->ui->listeners;
+	
 	if (count > 1) {
 		hildon_program_remove_window(program, window);
+		
+		/* Remove the listeners */
+		while (listeners != NULL) {
+			gconf_client_notify_remove(app_data->client, GPOINTER_TO_INT(listeners->data));
+			listeners = listeners->next;
+		}
+		
 		gtk_widget_destroy(GTK_WIDGET(window));
-		note->ui = NULL;
+		g_list_free(note->ui->listeners);
+		g_free(note->ui);
+		note->ui = g_new0(UserInterface, 1);
 		app_data->open_notes = g_list_remove(app_data->open_notes, note);
 		/* Don't free note, because we reuse this in the menu with the available notes and when reopening */
 	} else {
@@ -250,9 +261,15 @@ void note_delete(Note *note)
 	AppData *app_data = app_data_get();
 
 	/* Delete file */
+	if (!storage_delete_note(note->guid)) {
+		g_printerr("ERROR: The note with the guid %s could not be deleted \n", note->guid);
+	}
+		
+	/*
 	if (g_unlink(note->filename) == -1) {
 		g_printerr("ERROR: The file %s could not be deleted \n", note->filename);
 	}
+	*/
 
 	/* Remove from list store */
 	note_list_store_remove(app_data->note_store, note);
@@ -273,6 +290,9 @@ gboolean note_is_open(Note *note)
 	}
 }
 
+/** TODO: This should be a function of NoteListStore.
+ *  note_list_store_containts(note)
+ */
 gboolean note_exists(Note *note)
 {
 	AppData *app_data = app_data_get();
@@ -356,7 +376,7 @@ void note_show_new(Note *note)
 	/* TODO: Creating a new note should happen in note_create_new(). Not here. */
 	/* TODO: Only save guid in note and generate filename on-the-fly when needed. */
 	note->guid = get_uuid();
-	note->filename = (gchar*)note_get_new_filename(note->guid);
+	/*note->filename = (gchar*)note_get_new_filename(note->guid);*/
 
 	if (note->title == NULL) {
 		notes_count = note_list_store_get_length(app_data->note_store);
@@ -380,8 +400,8 @@ void note_show_existing(Note *note)
 	/* iter defines where to start with inserting */
 	gtk_text_buffer_get_start_iter(buffer, &iter);
 
-	/* start deserialization */
-	deserialize_note(note);
+	/* Insert the content of a note into the text buffer */
+	note_buffer_set_xml(buffer, note->content);
 
 	/* Set cursor possition */
 	gtk_text_buffer_get_iter_at_offset(buffer, &iter, note->cursor_position);
